@@ -511,7 +511,7 @@ def setup_logging():
     import logging
     logging.basicConfig(level=logging.INFO)
 
-# from http://stackoverflow.com/questions/22373927/get-traceback-of-warnings
+# From http://stackoverflow.com/questions/22373927/get-traceback-of-warnings
 # answered by mgab (2014-03-13)
 # edited by Gareth Rees (2015-11-28)
 def warn_with_traceback(message, category, filename, lineno,
@@ -715,8 +715,8 @@ def main():
 
         # If in batch mode then explicitly close the monitor file on completion
         if opts.batch:
-            sys.stderr.close()
-            sys.stderr = sys.__stderr__
+            sys.stdout.close()
+            sys.stdout = sys.__stdout__
 
         # Display the plots
         if not opts.batch and not opts.mpi and not opts.noshow:
